@@ -47,18 +47,20 @@ pub fn items(frontend_dir: Option<&PathBuf>, tauri_dir: Option<&Path>) -> Vec<Se
         if o.status.success() {
           let out = String::from_utf8_lossy(o.stdout.as_slice());
           let (package, version) = out.split_once(' ').unwrap_or_default();
-          let latest_ver = crate_latest_version(package).unwrap_or_default();
+          let version = version.strip_suffix('\n').unwrap_or(version);
+          let latest_version = crate_latest_version(package).unwrap_or_default();
           format!(
-            "{} {}: {}{}",
-            package,
-            "🦀",
-            version.split_once('\n').unwrap_or_default().0,
-            if !(version.is_empty() || latest_ver.is_empty()) {
-              let version = semver::Version::parse(version).unwrap();
-              let target_version = semver::Version::parse(latest_ver.as_str()).unwrap();
+            "{package} 🦀: {version}{}",
+            if !(version.is_empty() || latest_version.is_empty()) {
+              let current_version = semver::Version::parse(version).unwrap();
+              let target_version = semver::Version::parse(latest_version.as_str()).unwrap();
 
-              if version < target_version {
-                format!(" ({}, latest: {})", "outdated".yellow(), latest_ver.green())
+              if current_version < target_version {
+                format!(
+                  " ({}, latest: {})",
+                  "outdated".yellow(),
+                  latest_version.green()
+                )
               } else {
                 "".into()
               }
