@@ -191,6 +191,8 @@ pub fn target_triple() -> crate::Result<String> {
     "armv7"
   } else if cfg!(target_arch = "aarch64") {
     "aarch64"
+  } else if cfg!(target_arch = "riscv64") {
+    "riscv64"
   } else {
     return Err(crate::Error::Architecture);
   };
